summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2016-11-30 11:12:39 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2016-11-30 11:13:37 +0200
commit0b2801922d6972eeb607e37a8a1de210e825c95e (patch)
tree6c70c2c1b7abc3ffe5495f546e5ffe1ae358cd87 /include
parent70c03ec408360bb1285478b08bd7edcdbb090376 (diff)
rename getViewIndependentPrimitive2DSequence..
to getViewIndependentPrimitive2DContainer to match it's new return type Change-Id: I767bdef45316e355d49f6509ca1b50138a45b3fa
Diffstat (limited to 'include')
-rw-r--r--include/svx/sdr/contact/viewcontact.hxx4
-rw-r--r--include/svx/sdr/contact/viewcontactofsdrobj.hxx2
-rw-r--r--include/svx/sdr/contact/viewobjectcontact.hxx2
3 files changed, 4 insertions, 4 deletions
diff --git a/include/svx/sdr/contact/viewcontactofsdrobj.hxx b/include/svx/sdr/contact/viewcontactofsdrobj.hxx
index 81583a78932e..039bf4372d01 100644
--- a/include/svx/sdr/contact/viewcontactofsdrobj.hxx
+++ b/include/svx/sdr/contact/viewcontactofsdrobj.hxx
@@ -75,7 +75,7 @@ public:
virtual drawinglayer::primitive2d::Primitive2DContainer createGluePointPrimitive2DSequence() const override;
// allow embedding if needed (e.g. for SdrObjects, evtl. Name, Title and description get added). This
- // is a helper normally used from getViewIndependentPrimitive2DSequence(), but there is one exception
+ // is a helper normally used from getViewIndependentPrimitive2DContainer(), but there is one exception
// for 3D scenes
virtual drawinglayer::primitive2d::Primitive2DContainer embedToObjectSpecificInformation(const drawinglayer::primitive2d::Primitive2DContainer& rSource) const override;
};
diff --git a/include/svx/sdr/contact/viewobjectcontact.hxx b/include/svx/sdr/contact/viewobjectcontact.hxx
index 11ad3d80d622..b5b1a35bda5e 100644
--- a/include/svx/sdr/contact/viewobjectcontact.hxx
+++ b/include/svx/sdr/contact/viewobjectcontact.hxx
@@ -71,7 +71,7 @@ protected:
// This method is responsible for creating the graphical visualisation data which is
// stored/cached in the local primitive. Default gets view-independent Primitive
- // from the ViewContact using ViewContact::getViewIndependentPrimitive2DSequence(), takes care of
+ // from the ViewContact using ViewContact::getViewIndependentPrimitive2DContainer(), takes care of
// visibility, handles glue and ghosted.
// This method will not handle included hierarchies and not check geometric visibility.
virtual drawinglayer::primitive2d::Primitive2DContainer createPrimitive2DSequence(const DisplayInfo& rDisplayInfo) const;
diff --git a/include/svx/sdr/contact/viewcontact.hxx b/include/svx/sdr/contact/viewcontact.hxx
index 8e1a882b8a7c..20347120ed6c 100644
--- a/include/svx/sdr/contact/viewcontact.hxx
+++ b/include/svx/sdr/contact/viewcontact.hxx
@@ -122,13 +122,13 @@ public:
// access to the local primitive. This will ensure that the primitive is
// current in comparing the local one with a fresh created incarnation
- drawinglayer::primitive2d::Primitive2DContainer const & getViewIndependentPrimitive2DSequence() const;
+ drawinglayer::primitive2d::Primitive2DContainer const & getViewIndependentPrimitive2DContainer() const;
// add Gluepoints (if available)
virtual drawinglayer::primitive2d::Primitive2DContainer createGluePointPrimitive2DSequence() const;
// allow embedding if needed (e.g. for SdrObjects, evtl. Name, Title and description get added). This
// is a helper normally used from getViewIndependentPrimitive2DSequence(), but there is one exception
// for 3D scenes
virtual drawinglayer::primitive2d::Primitive2DContainer embedToObjectSpecificInformation(const drawinglayer::primitive2d::Primitive2DContainer& rSource) const;
@@ -122,13 +122,13 @@ public:
virtual drawinglayer::primitive2d::Primitive2DContainer createGluePointPrimitive2DSequence() const;
// allow embedding if needed (e.g. for SdrObjects, evtl. Name, Title and description get added). This
- // is a helper normally used from getViewIndependentPrimitive2DSequence(), but there is one exception
+ // is a helper normally used from getViewIndependentPrimitive2DContainer(), but there is one exception
// for 3D scenes
virtual drawinglayer::primitive2d::Primitive2DContainer embedToObjectSpecificInformation(const drawinglayer::primitive2d::Primitive2DContainer& rSource) const;